@@ -1,7 +1,5 @@
 /*
- * vi: formatoptions+=tc textwidth=80 tabstop=8 shiftwidth=8 noexpandtab:
- *
- * $Id: remote_info.h,v 1.19 2013/04/12 00:37:05 jaymzh Exp $
+ * vim:tw=80:ai:tabstop=4:softtabstop=4:shiftwidth=4:expandtab
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -485,6 +483,24 @@ static const TArchInfo ArchList[]={
 		"",				// usb
 	},
 	/* arch 16: 300 */
+	{
+		0,				// serial_location
+		0,				// serial_address
+		0,				// flash_base
+		0,				// firmware_base
+		0,				// config_base
+		0,				// firmware_update_base
+		0,				// firmware_4847_offset
+		0x4D505347,			// cookie
+		0,				// cookie_size
+		0,				// end_vector
+		"",				// micro
+		0,				// flash_size
+		0,				// ram_size
+		0,				// eeprom_size
+		"",				// usb
+	},
+	/* arch 17: Link */
 	{
 		0,				// serial_location
 		0,				// serial_address
